@@ -1,7 +1,7 @@
 #ifndef _RS_SQLite_H
 #define _RS_SQLite_H 1
 /*
- * $Id: RS-SQLite.h 213 2006-10-26 16:52:40Z sethf $
+ * $Id: RS-SQLite.h 222 2006-11-04 18:57:43Z sethf $
  *
  * Copyright (C) 1999-2002 The Omega Project for Statistical Computing.
  *
@@ -44,7 +44,7 @@ extern  "C" {
  */
 typedef struct st_sdbi_conParams {
   char *dbname;
-  int  mode;                     /* unused by SQLite as of 2.0.5 used */
+  int  loadable_extensions;
 } RS_SQLite_conParams;
 
 typedef struct st_sqlite_err {
@@ -52,7 +52,13 @@ typedef struct st_sqlite_err {
    char *errorMsg;
 } RS_SQLite_exception;
 
-RS_SQLite_conParams *RS_SQLite_allocConParams(const char *dbname, int mode);
+typedef struct st_sqlite_bindparam {
+  SEXPTYPE  type;
+  s_object *data;
+  int      is_protected;
+} RS_SQLite_bindParam;
+
+RS_SQLite_conParams *RS_SQLite_allocConParams(const char *dbname, int loadable_extensions);
 void                RS_SQLite_freeConParams(RS_SQLite_conParams *conParams);
 
 /* The following functions are the S/R entry into the C implementation (i.e.,
@@ -66,7 +72,8 @@ void                RS_SQLite_freeConParams(RS_SQLite_conParams *conParams);
  */
 
 /* dbManager */
-Mgr_Handle *RS_SQLite_init(s_object *config_params, s_object *reload);
+Mgr_Handle *RS_SQLite_init(s_object *config_params, s_object *reload,
+                           s_object *cache);
 s_object   *RS_SQLite_close(Mgr_Handle *mgrHandle);
 
 /* dbConnection */
@@ -90,7 +97,7 @@ int       RS_SQLite_stdCallback(void *resHandle, int ncol, char **row,
 
 /* dbResultSet */
 Res_Handle *RS_SQLite_exec(Con_Handle *conHandle, s_object *statement,
-                           s_object *s_limit);
+                           s_object *bind_data);
 s_object   *RS_SQLite_fetch(Res_Handle *rsHandle, s_object *max_rec);
 s_object   *RS_SQLite_closeResultSet(Res_Handle *rsHandle);
 void        RS_SQLite_initFields(RS_DBI_resultSet *res, int ncol,
@@ -99,6 +106,7 @@ void        RS_SQLite_initFields(RS_DBI_resultSet *res, int ncol,
 s_object   *RS_SQLite_validHandle(Db_Handle *handle);      /* boolean */
 
 RS_DBI_fields *RS_SQLite_createDataMappings(Res_Handle *resHandle);
+
 /* the following funs return named lists with meta-data for
  * the manager, connections, and  result sets, respectively.
  */
